@@ -125,50 +125,77 @@ class SerbCyr:
         "aparthejd",
         "ddor",
         "dss",
+        "džoov",
         "dvadesettrog",
         "epp",
         "fss",
         "gss",
         "interreakc",
         "interresor",
+        "ishod",
+        "ishran",
         "izzzdiovns",
-        "kock",
+        "jednook",
         "kss",
         "llsls",
         "mmf",
         "naddu",
         "natha",
         "natho",
+        "neeksplodiran",
+        "neophod",
+        "neshvać",
+        "neshvat",
+        "novoosnovan",
+        "novootkriven",
+        "obeshrabr",
         "ommetar",
+        "opho",
         "penthaus",
-        "palack",
+        "plavook",
         "poddirektor",
         "poddisciplin",
         "poddomen",
         "poddres",
+        "poobar",
+        "poodmak",
+        "poodras",
+        "pootpa",
+        "pooštr",
         "posthumn",
         "posttrans",
         "posttraum",
         "pothodni",
         "pothranj",
+        "pothva",
         "preddijabetes",
         "prekookean",
         "prethod",
+        "prevashod",
         "ptt",
+        "punkt",
+        "rashlad",
+        "rashod",
+        "samoodrž",
         "sbb",
         "sdss",
+        "shodno",
+        "shvać",
         "shvat",
+        "skocka",
+        "slepoo",
         "ssp",
         "ssrnj",
         "sssr",
         "superračun",
+        "svrsishod",
         "šopingholi",
         "tass",
-        "trocki",
         "transseks",
         "transsibir",
         "tridesettrog",
         "uppr",
+        "ushiće",
         "vannastav",
         "zoo"
     ]
@@ -316,14 +343,19 @@ class SerbCyr:
         'y',
         'é',
         'á',
+        'à',
         'ó',
+        'ò',
         'ü',
         'ö',
         'ä',
         'ê',
         'è',
         'ú',
+        'ù',
         'í',
+        'ì',
+        'ï',
         'ő',
         'ű',
         'ñ',
@@ -338,9 +370,9 @@ class SerbCyr:
         '&',
         '@',
         '#',
+        'ae',
         'bb',
         'cc',
-        'ck',
         'cs',
         'dd',
         'ee',
@@ -355,6 +387,7 @@ class SerbCyr:
         'mm',
         'nn',
         'ny',
+        'oe',
         'oo',
         'ph',
         'pp',
@@ -393,8 +426,7 @@ class SerbCyr:
             "blijedje",
             "bludje",
             "bridjе",
-            "vidjel",
-            "vidjet",
+            "vidje",
             "vindjakn",
             "višenedje",
             "vrijedje",
@@ -674,6 +706,7 @@ class SerbCyr:
         }
     }
 
+    # Main method that converts Latin text to Cyrillic
     def text_to_cyrillic(self, text):
         if len(text.strip()) == 0:
             return text
